/* SPDX-FileCopyrightText: © 2022-2024 Decompollaborate */
/* SPDX-License-Identifier: MIT */

/* Automatically generated. DO NOT MODIFY */

#ifndef RegisterDescriptor_Descriptors_arrays_h_automatic
#define RegisterDescriptor_Descriptors_arrays_h_automatic

const RabbitizerRegisterDescriptor RabbitizerRegister_GprO32_Descriptors[] = {
    [RABBITIZER_REG_GPR_O32_zero] = { .isZero=true },
    [RABBITIZER_REG_GPR_O32_at] = { .isClobberedByFuncCall=true, .isAt=true },
    [RABBITIZER_REG_GPR_O32_v0] = { .isClobberedByFuncCall=true, .isReturnReg=true },
    [RABBITIZER_REG_GPR_O32_v1] = { .isClobberedByFuncCall=true, .isReturnReg=true },
    [RABBITIZER_REG_GPR_O32_a0] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_O32_a1] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_O32_a2] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_O32_a3] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_O32_t0] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_t1] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_t2] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_t3] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_t4] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_t5] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_t6] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_t7] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_s0] = { .isSaved=true },
    [RABBITIZER_REG_GPR_O32_s1] = { .isSaved=true },
    [RABBITIZER_REG_GPR_O32_s2] = { .isSaved=true },
    [RABBITIZER_REG_GPR_O32_s3] = { .isSaved=true },
    [RABBITIZER_REG_GPR_O32_s4] = { .isSaved=true },
    [RABBITIZER_REG_GPR_O32_s5] = { .isSaved=true },
    [RABBITIZER_REG_GPR_O32_s6] = { .isSaved=true },
    [RABBITIZER_REG_GPR_O32_s7] = { .isSaved=true },
    [RABBITIZER_REG_GPR_O32_t8] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_t9] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_k0] = { .isKernel=true },
    [RABBITIZER_REG_GPR_O32_k1] = { .isKernel=true },
    [RABBITIZER_REG_GPR_O32_gp] = { .isGp=true },
    [RABBITIZER_REG_GPR_O32_sp] = { .isStackPointer=true },
    [RABBITIZER_REG_GPR_O32_fp] = { 0 },
    [RABBITIZER_REG_GPR_O32_ra] = { .isClobberedByFuncCall=true, .isRa=true },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_GprN32_Descriptors[] = {
    [RABBITIZER_REG_GPR_N32_zero] = { .isZero=true },
    [RABBITIZER_REG_GPR_N32_at] = { .isClobberedByFuncCall=true, .isAt=true },
    [RABBITIZER_REG_GPR_N32_v0] = { .isClobberedByFuncCall=true, .isReturnReg=true },
    [RABBITIZER_REG_GPR_N32_v1] = { .isClobberedByFuncCall=true, .isReturnReg=true },
    [RABBITIZER_REG_GPR_N32_a0] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_N32_a1] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_N32_a2] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_N32_a3] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_N32_a4] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_N32_a5] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_N32_a6] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_N32_a7] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_N32_t0] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_N32_t1] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_N32_t2] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_N32_t3] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_N32_s0] = { .isSaved=true },
    [RABBITIZER_REG_GPR_N32_s1] = { .isSaved=true },
    [RABBITIZER_REG_GPR_N32_s2] = { .isSaved=true },
    [RABBITIZER_REG_GPR_N32_s3] = { .isSaved=true },
    [RABBITIZER_REG_GPR_N32_s4] = { .isSaved=true },
    [RABBITIZER_REG_GPR_N32_s5] = { .isSaved=true },
    [RABBITIZER_REG_GPR_N32_s6] = { .isSaved=true },
    [RABBITIZER_REG_GPR_N32_s7] = { .isSaved=true },
    [RABBITIZER_REG_GPR_N32_t8] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_N32_t9] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_N32_k0] = { .isKernel=true },
    [RABBITIZER_REG_GPR_N32_k1] = { .isKernel=true },
    [RABBITIZER_REG_GPR_N32_gp] = { .isGp=true },
    [RABBITIZER_REG_GPR_N32_sp] = { .isStackPointer=true },
    [RABBITIZER_REG_GPR_N32_fp] = { 0 },
    [RABBITIZER_REG_GPR_N32_ra] = { .isClobberedByFuncCall=true, .isRa=true },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_Cop0_Descriptors[] = {
    [RABBITIZER_REG_COP0_Index] = { 0 },
    [RABBITIZER_REG_COP0_Random] = { 0 },
    [RABBITIZER_REG_COP0_EntryLo0] = { 0 },
    [RABBITIZER_REG_COP0_EntryLo1] = { 0 },
    [RABBITIZER_REG_COP0_Context] = { 0 },
    [RABBITIZER_REG_COP0_PageMask] = { 0 },
    [RABBITIZER_REG_COP0_Wired] = { 0 },
    [RABBITIZER_REG_COP0_Reserved07] = { .isReserved=true },
    [RABBITIZER_REG_COP0_BadVaddr] = { 0 },
    [RABBITIZER_REG_COP0_Count] = { 0 },
    [RABBITIZER_REG_COP0_EntryHi] = { 0 },
    [RABBITIZER_REG_COP0_Compare] = { 0 },
    [RABBITIZER_REG_COP0_Status] = { 0 },
    [RABBITIZER_REG_COP0_Cause] = { 0 },
    [RABBITIZER_REG_COP0_EPC] = { 0 },
    [RABBITIZER_REG_COP0_PRevID] = { 0 },
    [RABBITIZER_REG_COP0_Config] = { 0 },
    [RABBITIZER_REG_COP0_LLAddr] = { 0 },
    [RABBITIZER_REG_COP0_WatchLo] = { 0 },
    [RABBITIZER_REG_COP0_WatchHi] = { 0 },
    [RABBITIZER_REG_COP0_XContext] = { 0 },
    [RABBITIZER_REG_COP0_Reserved21] = { .isReserved=true },
    [RABBITIZER_REG_COP0_Reserved22] = { .isReserved=true },
    [RABBITIZER_REG_COP0_Reserved23] = { .isReserved=true },
    [RABBITIZER_REG_COP0_Reserved24] = { .isReserved=true },
    [RABBITIZER_REG_COP0_Reserved25] = { .isReserved=true },
    [RABBITIZER_REG_COP0_PErr] = { 0 },
    [RABBITIZER_REG_COP0_CacheErr] = { 0 },
    [RABBITIZER_REG_COP0_TagLo] = { 0 },
    [RABBITIZER_REG_COP0_TagHi] = { 0 },
    [RABBITIZER_REG_COP0_ErrorEPC] = { 0 },
    [RABBITIZER_REG_COP0_Reserved31] = { .isReserved=true },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_Cop1O32_Descriptors[] = {
    [RABBITIZER_REG_COP1_O32_fv0] = { 0 },
    [RABBITIZER_REG_COP1_O32_fv0f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fv1] = { 0 },
    [RABBITIZER_REG_COP1_O32_fv1f] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft0] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft0f] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft1] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft1f] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft2] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft2f] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft3] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft3f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fa0] = { 0 },
    [RABBITIZER_REG_COP1_O32_fa0f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fa1] = { 0 },
    [RABBITIZER_REG_COP1_O32_fa1f] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft4] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft4f] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft5] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft5f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs0] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs0f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs1] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs1f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs2] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs2f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs3] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs3f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs4] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs4f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs5] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs5f] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_Cop1N32_Descriptors[] = {
    [RABBITIZER_REG_COP1_N32_fv0] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft14] = { 0 },
    [RABBITIZER_REG_COP1_N32_fv1] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft15] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft0] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft1] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft2] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft3] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft4] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft5] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft6] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft7] = { 0 },
    [RABBITIZER_REG_COP1_N32_fa0] = { 0 },
    [RABBITIZER_REG_COP1_N32_fa1] = { 0 },
    [RABBITIZER_REG_COP1_N32_fa2] = { 0 },
    [RABBITIZER_REG_COP1_N32_fa3] = { 0 },
    [RABBITIZER_REG_COP1_N32_fa4] = { 0 },
    [RABBITIZER_REG_COP1_N32_fa5] = { 0 },
    [RABBITIZER_REG_COP1_N32_fa6] = { 0 },
    [RABBITIZER_REG_COP1_N32_fa7] = { 0 },
    [RABBITIZER_REG_COP1_N32_fs0] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft8] = { 0 },
    [RABBITIZER_REG_COP1_N32_fs1] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft9] = { 0 },
    [RABBITIZER_REG_COP1_N32_fs2] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft10] = { 0 },
    [RABBITIZER_REG_COP1_N32_fs3] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft11] = { 0 },
    [RABBITIZER_REG_COP1_N32_fs4] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft12] = { 0 },
    [RABBITIZER_REG_COP1_N32_fs5] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft13] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_Cop1N64_Descriptors[] = {
    [RABBITIZER_REG_COP1_N64_fv0] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft12] = { 0 },
    [RABBITIZER_REG_COP1_N64_fv1] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft13] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft0] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft1] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft2] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft3] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft4] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft5] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft6] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft7] = { 0 },
    [RABBITIZER_REG_COP1_N64_fa0] = { 0 },
    [RABBITIZER_REG_COP1_N64_fa1] = { 0 },
    [RABBITIZER_REG_COP1_N64_fa2] = { 0 },
    [RABBITIZER_REG_COP1_N64_fa3] = { 0 },
    [RABBITIZER_REG_COP1_N64_fa4] = { 0 },
    [RABBITIZER_REG_COP1_N64_fa5] = { 0 },
    [RABBITIZER_REG_COP1_N64_fa6] = { 0 },
    [RABBITIZER_REG_COP1_N64_fa7] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft8] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft9] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft10] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft11] = { 0 },
    [RABBITIZER_REG_COP1_N64_fs0] = { 0 },
    [RABBITIZER_REG_COP1_N64_fs1] = { 0 },
    [RABBITIZER_REG_COP1_N64_fs2] = { 0 },
    [RABBITIZER_REG_COP1_N64_fs3] = { 0 },
    [RABBITIZER_REG_COP1_N64_fs4] = { 0 },
    [RABBITIZER_REG_COP1_N64_fs5] = { 0 },
    [RABBITIZER_REG_COP1_N64_fs6] = { 0 },
    [RABBITIZER_REG_COP1_N64_fs7] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_Cop1Control_Descriptors[] = {
    [RABBITIZER_REG_COP1_CONTROL_0] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_1] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_2] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_3] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_4] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_5] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_6] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_7] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_8] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_9] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_10] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_11] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_12] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_13] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_14] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_15] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_16] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_17] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_18] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_19] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_20] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_21] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_22] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_23] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_24] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_25] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_26] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_27] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_28] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_29] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_30] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_FpcCsr] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_Cop2_Descriptors[] = {
    [RABBITIZER_REG_COP2_0] = { 0 },
    [RABBITIZER_REG_COP2_1] = { 0 },
    [RABBITIZER_REG_COP2_2] = { 0 },
    [RABBITIZER_REG_COP2_3] = { 0 },
    [RABBITIZER_REG_COP2_4] = { 0 },
    [RABBITIZER_REG_COP2_5] = { 0 },
    [RABBITIZER_REG_COP2_6] = { 0 },
    [RABBITIZER_REG_COP2_7] = { 0 },
    [RABBITIZER_REG_COP2_8] = { 0 },
    [RABBITIZER_REG_COP2_9] = { 0 },
    [RABBITIZER_REG_COP2_10] = { 0 },
    [RABBITIZER_REG_COP2_11] = { 0 },
    [RABBITIZER_REG_COP2_12] = { 0 },
    [RABBITIZER_REG_COP2_13] = { 0 },
    [RABBITIZER_REG_COP2_14] = { 0 },
    [RABBITIZER_REG_COP2_15] = { 0 },
    [RABBITIZER_REG_COP2_16] = { 0 },
    [RABBITIZER_REG_COP2_17] = { 0 },
    [RABBITIZER_REG_COP2_18] = { 0 },
    [RABBITIZER_REG_COP2_19] = { 0 },
    [RABBITIZER_REG_COP2_20] = { 0 },
    [RABBITIZER_REG_COP2_21] = { 0 },
    [RABBITIZER_REG_COP2_22] = { 0 },
    [RABBITIZER_REG_COP2_23] = { 0 },
    [RABBITIZER_REG_COP2_24] = { 0 },
    [RABBITIZER_REG_COP2_25] = { 0 },
    [RABBITIZER_REG_COP2_26] = { 0 },
    [RABBITIZER_REG_COP2_27] = { 0 },
    [RABBITIZER_REG_COP2_28] = { 0 },
    [RABBITIZER_REG_COP2_29] = { 0 },
    [RABBITIZER_REG_COP2_30] = { 0 },
    [RABBITIZER_REG_COP2_31] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_RspGpr_Descriptors[] = {
    [RABBITIZER_REG_RSP_GPR_zero] = { .isZero=true },
    [RABBITIZER_REG_RSP_GPR_1] = { 0 },
    [RABBITIZER_REG_RSP_GPR_2] = { 0 },
    [RABBITIZER_REG_RSP_GPR_3] = { 0 },
    [RABBITIZER_REG_RSP_GPR_4] = { 0 },
    [RABBITIZER_REG_RSP_GPR_5] = { 0 },
    [RABBITIZER_REG_RSP_GPR_6] = { 0 },
    [RABBITIZER_REG_RSP_GPR_7] = { 0 },
    [RABBITIZER_REG_RSP_GPR_8] = { 0 },
    [RABBITIZER_REG_RSP_GPR_9] = { 0 },
    [RABBITIZER_REG_RSP_GPR_10] = { 0 },
    [RABBITIZER_REG_RSP_GPR_11] = { 0 },
    [RABBITIZER_REG_RSP_GPR_12] = { 0 },
    [RABBITIZER_REG_RSP_GPR_13] = { 0 },
    [RABBITIZER_REG_RSP_GPR_14] = { 0 },
    [RABBITIZER_REG_RSP_GPR_15] = { 0 },
    [RABBITIZER_REG_RSP_GPR_16] = { 0 },
    [RABBITIZER_REG_RSP_GPR_17] = { 0 },
    [RABBITIZER_REG_RSP_GPR_18] = { 0 },
    [RABBITIZER_REG_RSP_GPR_19] = { 0 },
    [RABBITIZER_REG_RSP_GPR_20] = { 0 },
    [RABBITIZER_REG_RSP_GPR_21] = { 0 },
    [RABBITIZER_REG_RSP_GPR_22] = { 0 },
    [RABBITIZER_REG_RSP_GPR_23] = { 0 },
    [RABBITIZER_REG_RSP_GPR_24] = { 0 },
    [RABBITIZER_REG_RSP_GPR_25] = { 0 },
    [RABBITIZER_REG_RSP_GPR_26] = { 0 },
    [RABBITIZER_REG_RSP_GPR_27] = { 0 },
    [RABBITIZER_REG_RSP_GPR_28] = { 0 },
    [RABBITIZER_REG_RSP_GPR_29] = { 0 },
    [RABBITIZER_REG_RSP_GPR_30] = { 0 },
    [RABBITIZER_REG_RSP_GPR_ra] = { .isClobberedByFuncCall=true, .isRa=true },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_RspCop0_Descriptors[] = {
    [RABBITIZER_REG_RSP_COP0_SP_MEM_ADDR] = { 0 },
    [RABBITIZER_REG_RSP_COP0_SP_DRAM_ADDR] = { 0 },
    [RABBITIZER_REG_RSP_COP0_SP_RD_LEN] = { 0 },
    [RABBITIZER_REG_RSP_COP0_SP_WR_LEN] = { 0 },
    [RABBITIZER_REG_RSP_COP0_SP_STATUS] = { 0 },
    [RABBITIZER_REG_RSP_COP0_SP_DMA_FULL] = { 0 },
    [RABBITIZER_REG_RSP_COP0_SP_DMA_BUSY] = { 0 },
    [RABBITIZER_REG_RSP_COP0_SP_SEMAPHORE] = { 0 },
    [RABBITIZER_REG_RSP_COP0_DPC_START] = { 0 },
    [RABBITIZER_REG_RSP_COP0_DPC_END] = { 0 },
    [RABBITIZER_REG_RSP_COP0_DPC_CURRENT] = { 0 },
    [RABBITIZER_REG_RSP_COP0_DPC_STATUS] = { 0 },
    [RABBITIZER_REG_RSP_COP0_DPC_CLOCK] = { 0 },
    [RABBITIZER_REG_RSP_COP0_DPC_BUFBUSY] = { 0 },
    [RABBITIZER_REG_RSP_COP0_DPC_PIPEBUSY] = { 0 },
    [RABBITIZER_REG_RSP_COP0_DPC_TMEM] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_RspCop2_Descriptors[] = {
    [RABBITIZER_REG_RSP_COP2_0] = { 0 },
    [RABBITIZER_REG_RSP_COP2_1] = { 0 },
    [RABBITIZER_REG_RSP_COP2_2] = { 0 },
    [RABBITIZER_REG_RSP_COP2_3] = { 0 },
    [RABBITIZER_REG_RSP_COP2_4] = { 0 },
    [RABBITIZER_REG_RSP_COP2_5] = { 0 },
    [RABBITIZER_REG_RSP_COP2_6] = { 0 },
    [RABBITIZER_REG_RSP_COP2_7] = { 0 },
    [RABBITIZER_REG_RSP_COP2_8] = { 0 },
    [RABBITIZER_REG_RSP_COP2_9] = { 0 },
    [RABBITIZER_REG_RSP_COP2_10] = { 0 },
    [RABBITIZER_REG_RSP_COP2_11] = { 0 },
    [RABBITIZER_REG_RSP_COP2_12] = { 0 },
    [RABBITIZER_REG_RSP_COP2_13] = { 0 },
    [RABBITIZER_REG_RSP_COP2_14] = { 0 },
    [RABBITIZER_REG_RSP_COP2_15] = { 0 },
    [RABBITIZER_REG_RSP_COP2_16] = { 0 },
    [RABBITIZER_REG_RSP_COP2_17] = { 0 },
    [RABBITIZER_REG_RSP_COP2_18] = { 0 },
    [RABBITIZER_REG_RSP_COP2_19] = { 0 },
    [RABBITIZER_REG_RSP_COP2_20] = { 0 },
    [RABBITIZER_REG_RSP_COP2_21] = { 0 },
    [RABBITIZER_REG_RSP_COP2_22] = { 0 },
    [RABBITIZER_REG_RSP_COP2_23] = { 0 },
    [RABBITIZER_REG_RSP_COP2_24] = { 0 },
    [RABBITIZER_REG_RSP_COP2_25] = { 0 },
    [RABBITIZER_REG_RSP_COP2_26] = { 0 },
    [RABBITIZER_REG_RSP_COP2_27] = { 0 },
    [RABBITIZER_REG_RSP_COP2_28] = { 0 },
    [RABBITIZER_REG_RSP_COP2_29] = { 0 },
    [RABBITIZER_REG_RSP_COP2_30] = { 0 },
    [RABBITIZER_REG_RSP_COP2_31] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_RspCop2Control_Descriptors[] = {
    [RABBITIZER_REG_RSP_COP2_CONTROL_0] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_1] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_2] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_3] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_4] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_5] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_6] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_7] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_8] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_9] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_10] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_11] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_12] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_13] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_14] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_15] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_16] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_17] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_18] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_19] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_20] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_21] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_22] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_23] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_24] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_25] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_26] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_27] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_28] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_29] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_30] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_31] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_RspVector_Descriptors[] = {
    [RABBITIZER_REG_RSP_VECTOR_v0] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v1] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v2] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v3] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v4] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v5] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v6] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v7] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v8] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v9] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v10] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v11] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v12] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v13] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v14] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v15] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v16] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v17] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v18] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v19] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v20] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v21] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v22] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v23] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v24] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v25] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v26] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v27] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v28] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v29] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v30] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v31] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_R4000AllegrexS_Descriptors[] = {
    [RABBITIZER_REG_R4000ALLEGREX_S_S000] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S010] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S020] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S030] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S100] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S110] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S120] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S130] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S200] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S210] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S220] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S230] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S300] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S310] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S320] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S330] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S400] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S410] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S420] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S430] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S500] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S510] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S520] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S530] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S600] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S610] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S620] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S630] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S700] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S710] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S720] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S730] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S001] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S011] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S021] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S031] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S101] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S111] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S121] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S131] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S201] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S211] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S221] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S231] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S301] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S311] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S321] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S331] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S401] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S411] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S421] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S431] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S501] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S511] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S521] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S531] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S601] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S611] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S621] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S631] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S701] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S711] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S721] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S731] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S002] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S012] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S022] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S032] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S102] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S112] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S122] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S132] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S202] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S212] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S222] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S232] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S302] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S312] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S322] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S332] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S402] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S412] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S422] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S432] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S502] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S512] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S522] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S532] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S602] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S612] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S622] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S632] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S702] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S712] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S722] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S732] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S003] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S013] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S023] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S033] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S103] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S113] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S123] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S133] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S203] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S213] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S223] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S233] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S303] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S313] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S323] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S333] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S403] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S413] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S423] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S433] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S503] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S513] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S523] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S533] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S603] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S613] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S623] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S633] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S703] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S713] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S723] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_S_S733] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_R4000AllegrexV2D_Descriptors[] = {
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C000] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C010] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C020] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C030] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C100] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C110] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C120] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C130] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C200] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C210] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C220] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C230] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C300] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C310] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C320] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C330] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C400] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C410] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C420] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C430] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C500] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C510] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C520] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C530] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C600] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C610] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C620] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C630] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C700] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C710] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C720] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C730] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R000] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R001] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R002] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R003] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R100] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R101] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R102] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R103] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R200] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R201] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R202] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R203] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R300] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R301] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R302] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R303] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R400] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R401] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R402] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R403] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R500] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R501] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R502] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R503] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R600] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R601] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R602] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R603] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R700] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R701] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R702] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R703] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C002] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C012] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C022] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C032] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C102] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C112] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C122] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C132] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C202] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C212] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C222] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C232] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C302] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C312] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C322] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C332] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C402] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C412] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C422] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C432] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C502] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C512] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C522] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C532] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C602] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C612] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C622] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C632] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C702] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C712] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C722] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_C732] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R020] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R021] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R022] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R023] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R120] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R121] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R122] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R123] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R220] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R221] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R222] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R223] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R320] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R321] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R322] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R323] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R420] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R421] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R422] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R423] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R520] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R521] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R522] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R523] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R620] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R621] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R622] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R623] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R720] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R721] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R722] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V2D_R723] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_R4000AllegrexV3D_Descriptors[] = {
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C000] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C010] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C020] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C030] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C100] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C110] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C120] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C130] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C200] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C210] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C220] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C230] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C300] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C310] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C320] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C330] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C400] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C410] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C420] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C430] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C500] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C510] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C520] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C530] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C600] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C610] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C620] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C630] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C700] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C710] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C720] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C730] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R000] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R001] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R002] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R003] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R100] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R101] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R102] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R103] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R200] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R201] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R202] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R203] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R300] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R301] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R302] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R303] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R400] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R401] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R402] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R403] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R500] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R501] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R502] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R503] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R600] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R601] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R602] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R603] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R700] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R701] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R702] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R703] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C001] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C011] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C021] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C031] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C101] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C111] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C121] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C131] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C201] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C211] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C221] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C231] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C301] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C311] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C321] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C331] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C401] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C411] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C421] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C431] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C501] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C511] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C521] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C531] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C601] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C611] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C621] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C631] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C701] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C711] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C721] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_C731] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R010] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R011] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R012] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R013] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R110] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R111] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R112] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R113] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R210] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R211] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R212] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R213] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R310] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R311] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R312] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R313] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R410] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R411] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R412] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R413] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R510] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R511] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R512] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R513] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R610] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R611] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R612] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R613] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R710] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R711] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R712] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V3D_R713] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_R4000AllegrexV4D_Descriptors[] = {
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C000] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C010] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C020] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C030] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C100] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C110] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C120] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C130] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C200] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C210] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C220] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C230] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C300] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C310] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C320] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C330] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C400] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C410] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C420] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C430] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C500] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C510] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C520] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C530] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C600] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C610] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C620] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C630] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C700] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C710] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C720] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C730] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R000] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R001] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R002] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R003] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R100] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R101] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R102] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R103] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R200] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R201] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R202] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R203] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R300] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R301] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R302] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R303] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R400] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R401] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R402] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R403] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R500] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R501] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R502] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R503] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R600] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R601] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R602] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R603] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R700] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R701] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R702] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R703] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C002] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C012] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C022] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C032] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C102] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C112] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C122] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C132] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C202] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C212] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C222] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C232] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C302] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C312] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C322] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C332] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C402] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C412] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C422] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C432] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C502] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C512] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C522] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C532] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C602] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C612] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C622] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C632] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C702] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C712] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C722] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_C732] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R020] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R021] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R022] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R023] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R120] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R121] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R122] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R123] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R220] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R221] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R222] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R223] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R320] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R321] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R322] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R323] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R420] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R421] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R422] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R423] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R520] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R521] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R522] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R523] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R620] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R621] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R622] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R623] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R720] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R721] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R722] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_V4D_R723] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_R4000AllegrexM2x2_Descriptors[] = {
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M000] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M010] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M020] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M030] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M100] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M110] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M120] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M130] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M200] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M210] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M220] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M230] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M300] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M310] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M320] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M330] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M400] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M410] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M420] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M430] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M500] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M510] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M520] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M530] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M600] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M610] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M620] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M630] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M700] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M710] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M720] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M730] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E000] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E001] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E002] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E003] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E100] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E101] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E102] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E103] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E200] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E201] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E202] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E203] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E300] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E301] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E302] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E303] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E400] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E401] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E402] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E403] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E500] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E501] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E502] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E503] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E600] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E601] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E602] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E603] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E700] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E701] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E702] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E703] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M002] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M012] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M022] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M032] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M102] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M112] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M122] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M132] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M202] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M212] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M222] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M232] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M302] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M312] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M322] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M332] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M402] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M412] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M422] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M432] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M502] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M512] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M522] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M532] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M602] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M612] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M622] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M632] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M702] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M712] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M722] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_M732] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E020] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E021] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E022] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E023] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E120] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E121] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E122] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E123] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E220] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E221] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E222] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E223] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E320] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E321] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E322] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E323] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E420] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E421] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E422] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E423] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E520] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E521] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E522] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E523] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E620] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E621] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E622] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E623] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E720] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E721] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E722] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M2X2_E723] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_R4000AllegrexM3x3_Descriptors[] = {
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M000] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M010] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M020] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M030] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M100] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M110] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M120] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M130] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M200] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M210] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M220] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M230] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M300] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M310] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M320] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M330] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M400] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M410] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M420] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M430] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M500] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M510] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M520] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M530] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M600] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M610] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M620] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M630] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M700] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M710] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M720] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M730] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E000] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E001] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E002] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E003] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E100] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E101] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E102] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E103] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E200] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E201] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E202] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E203] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E300] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E301] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E302] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E303] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E400] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E401] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E402] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E403] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E500] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E501] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E502] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E503] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E600] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E601] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E602] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E603] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E700] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E701] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E702] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E703] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M001] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M011] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M021] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M031] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M101] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M111] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M121] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M131] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M201] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M211] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M221] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M231] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M301] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M311] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M321] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M331] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M401] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M411] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M421] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M431] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M501] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M511] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M521] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M531] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M601] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M611] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M621] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M631] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M701] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M711] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M721] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_M731] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E010] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E011] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E012] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E013] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E110] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E111] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E112] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E113] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E210] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E211] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E212] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E213] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E310] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E311] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E312] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E313] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E410] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E411] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E412] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E413] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E510] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E511] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E512] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E513] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E610] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E611] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E612] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E613] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E710] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E711] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E712] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M3X3_E713] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_R4000AllegrexM4x4_Descriptors[] = {
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M000] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M010] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M020] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M030] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M100] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M110] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M120] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M130] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M200] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M210] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M220] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M230] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M300] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M310] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M320] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M330] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M400] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M410] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M420] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M430] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M500] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M510] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M520] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M530] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M600] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M610] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M620] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M630] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M700] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M710] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M720] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M730] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E000] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E001] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E002] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E003] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E100] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E101] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E102] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E103] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E200] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E201] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E202] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E203] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E300] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E301] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E302] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E303] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E400] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E401] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E402] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E403] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E500] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E501] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E502] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E503] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E600] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E601] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E602] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E603] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E700] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E701] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E702] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E703] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M002] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M012] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M022] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M032] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M102] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M112] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M122] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M132] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M202] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M212] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M222] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M232] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M302] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M312] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M322] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M332] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M402] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M412] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M422] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M432] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M502] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M512] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M522] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M532] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M602] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M612] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M622] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M632] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M702] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M712] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M722] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_M732] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E020] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E021] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E022] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E023] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E120] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E121] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E122] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E123] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E220] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E221] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E222] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E223] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E320] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E321] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E322] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E323] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E420] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E421] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E422] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E423] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E520] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E521] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E522] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E523] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E620] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E621] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E622] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E623] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E720] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E721] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E722] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_M4X4_E723] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_R4000AllegrexVfpuControl_Descriptors[] = {
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_PFXS] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_PFXT] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_PFXD] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_CC] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_INF4] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RSV5] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RSV6] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_REV] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RCX0] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RCX1] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RCX2] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RCX3] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RCX4] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RCX5] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RCX6] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_VFPU_RCX7] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_144] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_145] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_146] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_147] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_148] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_149] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_150] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_151] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_152] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_153] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_154] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_155] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_156] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_157] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_158] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_159] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_160] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_161] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_162] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_163] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_164] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_165] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_166] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_167] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_168] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_169] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_170] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_171] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_172] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_173] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_174] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_175] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_176] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_177] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_178] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_179] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_180] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_181] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_182] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_183] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_184] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_185] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_186] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_187] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_188] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_189] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_190] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_191] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_192] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_193] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_194] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_195] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_196] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_197] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_198] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_199] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_200] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_201] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_202] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_203] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_204] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_205] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_206] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_207] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_208] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_209] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_210] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_211] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_212] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_213] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_214] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_215] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_216] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_217] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_218] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_219] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_220] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_221] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_222] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_223] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_224] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_225] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_226] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_227] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_228] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_229] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_230] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_231] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_232] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_233] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_234] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_235] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_236] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_237] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_238] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_239] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_240] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_241] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_242] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_243] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_244] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_245] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_246] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_247] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_248] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_249] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_250] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_251] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_252] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_253] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_254] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VFPUCONTROL_255] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_R4000AllegrexVConstant_Descriptors[] = {
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_0] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_HUGE] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_SQRT2] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_SQRT1_2] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_2_SQRTPI] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_2_PI] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_1_PI] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_PI_4] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_PI_2] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_PI] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_E] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_LOG2E] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_LOG10E] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_LN2] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_LN10] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_2PI] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_PI_6] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_LOG10TWO] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_LOG2TEN] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_VFPU_SQRT3_2] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_20] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_21] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_22] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_23] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_24] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_25] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_26] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_27] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_28] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_29] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_30] = { 0 },
    [RABBITIZER_REG_R4000ALLEGREX_VCONSTANT_INVALID_31] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_R5900VF_Descriptors[] = {
    [RABBITIZER_REG_R5900_VF_vf0] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf1] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf2] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf3] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf4] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf5] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf6] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf7] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf8] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf9] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf10] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf11] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf12] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf13] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf14] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf15] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf16] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf17] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf18] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf19] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf20] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf21] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf22] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf23] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf24] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf25] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf26] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf27] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf28] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf29] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf30] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf31] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_R5900VI_Descriptors[] = {
    [RABBITIZER_REG_R5900_VI_vi0] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi1] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi2] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi3] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi4] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi5] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi6] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi7] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi8] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi9] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi10] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi11] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi12] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi13] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi14] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi15] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi16] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi17] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi18] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi19] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi20] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi21] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi22] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi23] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi24] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi25] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi26] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi27] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi28] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi29] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi30] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi31] = { 0 },
};

#endif
